@@ -72,8 +72,9 @@ extern crate bytecodec;
 #[macro_use]
 extern crate trackable;
 
-pub use body::{BodyDecode, BodyDecoder, BodyEncode, BodyEncoder, HeadBodyEncoder, NoBodyDecoder,
-               NoBodyEncoder};
+pub use body::{
+    BodyDecode, BodyDecoder, BodyEncode, BodyEncoder, HeadBodyEncoder, NoBodyDecoder, NoBodyEncoder,
+};
 pub use header::{Header, HeaderField, HeaderFields, HeaderMut};
 pub use method::Method;
 pub use options::DecodeOptions;
